@@ -47,11 +47,12 @@ class ArchiveBasedAbstractParser(abstract.AbstractParser):
 
     def __init__(self, filename):
         super().__init__(filename)
-        self.archive_class = None  #  type: Optional[ArchiveClass]
-        self.member_class = None  #  type: Optional[ArchiveMember]
+        # We ignore typing here because mypy is too stupid
+        self.archive_class = None  #  type: ignore
+        self.member_class = None  #  type: ignore
 
         # Those are the files that have a format that _isn't_
-        # supported by MAT2, but that we want to keep anyway.
+        # supported by mat2, but that we want to keep anyway.
         self.files_to_keep = set()  # type: Set[Pattern]
 
         # Those are the files that we _do not_ want to keep,
@@ -62,7 +63,9 @@ class ArchiveBasedAbstractParser(abstract.AbstractParser):
         # the archive?
         self.unknown_member_policy = UnknownMemberPolicy.ABORT  # type: UnknownMemberPolicy
 
-        self.is_archive_valid()
+        # The LGTM comment is to mask a false-positive,
+        # see https://lgtm.com/projects/g/jvoisin/mat2/
+        self.is_archive_valid()  # lgtm [py/init-calls-subclass]
 
     def is_archive_valid(self):
         """Raise a ValueError is the current archive isn't a valid one."""
@@ -80,28 +83,27 @@ class ArchiveBasedAbstractParser(abstract.AbstractParser):
         return {}  # pragma: no cover
 
     @staticmethod
-    @abc.abstractstaticmethod
+    @abc.abstractmethod
     def _get_all_members(archive: ArchiveClass) -> List[ArchiveMember]:
         """Return all the members of the archive."""
 
     @staticmethod
-    @abc.abstractstaticmethod
+    @abc.abstractmethod
     def _clean_member(member: ArchiveMember) -> ArchiveMember:
         """Remove all the metadata for a given member."""
 
     @staticmethod
-    @abc.abstractstaticmethod
+    @abc.abstractmethod
     def _get_member_meta(member: ArchiveMember) -> Dict[str, str]:
         """Return all the metadata of a given member."""
 
     @staticmethod
-    @abc.abstractstaticmethod
+    @abc.abstractmethod
     def _get_member_name(member: ArchiveMember) -> str:
         """Return the name of the given member."""
 
-    @staticmethod
-    @abc.abstractstaticmethod
-    def _add_file_to_archive(archive: ArchiveClass, member: ArchiveMember,
+    @abc.abstractmethod
+    def _add_file_to_archive(self, archive: ArchiveClass, member: ArchiveMember,
                              full_path: str):
         """Add the file at full_path to the archive, via the given member."""
 
@@ -197,7 +199,7 @@ class ArchiveBasedAbstractParser(abstract.AbstractParser):
                             logging.warning("In file %s, keeping unknown element %s (format: %s)",
                                             self.filename, member_name, mtype)
                         else:
-                            logging.error("In file %s, element %s's format (%s) " \
+                            logging.error("In file %s, element %s's format (%s) "
                                           "isn't supported",
                                           self.filename, member_name, mtype)
                             abort = True
@@ -313,8 +315,7 @@ class TarParser(ArchiveBasedAbstractParser):
             metadata['gname'] = member.gname
         return metadata
 
-    @staticmethod
-    def _add_file_to_archive(archive: ArchiveClass, member: ArchiveMember,
+    def _add_file_to_archive(self, archive: ArchiveClass, member: ArchiveMember,
                              full_path: str):
         assert isinstance(member, tarfile.TarInfo)  # please mypy
         assert isinstance(archive, tarfile.TarFile)  # please mypy
@@ -358,6 +359,7 @@ class ZipParser(ArchiveBasedAbstractParser):
         super().__init__(filename)
         self.archive_class = zipfile.ZipFile
         self.member_class = zipfile.ZipInfo
+        self.zip_compression_type = zipfile.ZIP_DEFLATED
 
     def is_archive_valid(self):
         try:
@@ -392,13 +394,13 @@ class ZipParser(ArchiveBasedAbstractParser):
 
         return metadata
 
-    @staticmethod
-    def _add_file_to_archive(archive: ArchiveClass, member: ArchiveMember,
+    def _add_file_to_archive(self, archive: ArchiveClass, member: ArchiveMember,
                              full_path: str):
         assert isinstance(archive, zipfile.ZipFile)  # please mypy
         assert isinstance(member, zipfile.ZipInfo)  # please mypy
         with open(full_path, 'rb') as f:
-            archive.writestr(member, f.read())
+            archive.writestr(member, f.read(),
+                             compress_type=self.zip_compression_type)
 
     @staticmethod
     def _get_all_members(archive: ArchiveClass) -> List[ArchiveMember]:
