@@ -44,6 +44,12 @@ def _sort_xml_attributes(full_path: str) -> bool:
 
 
 class MSOfficeParser(ZipParser):
+    """
+    The methods modifying XML documents are usually doing so in two loops:
+        1. finding the tag/attributes to remove;
+        2. actually editing the document
+    since it's tricky to modify the XML while iterating on it.
+    """
     mimetypes = {
         'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
         'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
@@ -62,9 +68,6 @@ class MSOfficeParser(ZipParser):
 
         # Do we want to keep the following ones?
         'application/vnd.openxmlformats-officedocument.wordprocessingml.settings+xml',
-
-        # See https://0xacab.org/jvoisin/mat2/issues/71
-        'application/vnd.openxmlformats-officedocument.wordprocessingml.numbering+xml',  # /word/numbering.xml
     }
 
 
@@ -74,24 +77,31 @@ class MSOfficeParser(ZipParser):
         self.files_to_keep = set(map(re.compile, {  # type: ignore
             r'^\[Content_Types\]\.xml$',
             r'^_rels/\.rels$',
-            r'^word/_rels/document\.xml\.rels$',
-            r'^word/_rels/footer[0-9]*\.xml\.rels$',
-            r'^word/_rels/header[0-9]*\.xml\.rels$',
+            r'^(?:word|ppt)/_rels/document\.xml\.rels$',
+            r'^(?:word|ppt)/_rels/footer[0-9]*\.xml\.rels$',
+            r'^(?:word|ppt)/_rels/header[0-9]*\.xml\.rels$',
+            r'^ppt/slideLayouts/_rels/slideLayout[0-9]+\.xml\.rels$',
 
             # https://msdn.microsoft.com/en-us/library/dd908153(v=office.12).aspx
-            r'^word/stylesWithEffects\.xml$',
+            r'^(?:word|ppt)/stylesWithEffects\.xml$',
         }))
         self.files_to_omit = set(map(re.compile, {  # type: ignore
             r'^customXml/',
             r'webSettings\.xml$',
             r'^docProps/custom\.xml$',
-            r'^word/printerSettings/',
-            r'^word/theme',
-            r'^word/people\.xml$',
+            r'^(?:word|ppt)/printerSettings/',
+            r'^(?:word|ppt)/theme',
+            r'^(?:word|ppt)/people\.xml$',
+            r'^(?:word|ppt)/numbering\.xml$',
+            # View properties like view mode, last viewed slide etc
+            r'^(?:word|ppt)/viewProps\.xml$',
+            # Additional presentation-wide properties like printing properties,
+            # presentation show properties etc.
+            r'^(?:word|ppt)/presProps\.xml$',
 
             # we have an allowlist in self.files_to_keep,
             # so we can trash everything else
-            r'^word/_rels/',
+            r'^(?:word|ppt)/_rels/',
         }))
 
         if self.__fill_files_to_keep_via_content_types() is False:
@@ -124,20 +134,18 @@ class MSOfficeParser(ZipParser):
 
     @staticmethod
     def __remove_rsid(full_path: str) -> bool:
-        """ The method will remove "revision session ID".  We're '}rsid'
+        """ The method will remove "revision session ID".  We're using '}rsid'
         instead of proper parsing, since rsid can have multiple forms, like
         `rsidRDefault`, `rsidR`, `rsids`, …
 
-        We're removing rsid tags in two times, because we can't modify
-        the xml while we're iterating on it.
-
         For more details, see
         - https://msdn.microsoft.com/en-us/library/office/documentformat.openxml.wordprocessing.previoussectionproperties.rsidrpr.aspx
         - https://blogs.msdn.microsoft.com/brian_jones/2006/12/11/whats-up-with-all-those-rsids/
         """
         try:
             tree, namespace = _parse_xml(full_path)
-        except ET.ParseError:
+        except ET.ParseError as e:
+            logging.error("Unable to parse %s: %s", full_path, e)
             return False
 
         # rsid, tags or attributes, are always under the `w` namespace
@@ -162,11 +170,38 @@ class MSOfficeParser(ZipParser):
         return True
 
     @staticmethod
-    def __remove_revisions(full_path: str) -> bool:
-        """ In this function, we're changing the XML document in several
-        different times, since we don't want to change the tree we're currently
-        iterating on.
+    def __remove_nsid(full_path: str) -> bool:
         """
+        nsid are random identifiers that can be used to ease the merging of
+        some components of a document.  They can also be used for
+        fingerprinting.
+
+        See the spec for more details: https://docs.microsoft.com/en-us/dotnet/api/documentformat.openxml.wordprocessing.nsid?view=openxml-2.8.1
+        """
+        try:
+            tree, namespace = _parse_xml(full_path)
+        except ET.ParseError as e:  # pragma: no cover
+            logging.error("Unable to parse %s: %s", full_path, e)
+            return False
+
+        # The nsid tag is always under the `w` namespace
+        if 'w' not in namespace.keys():
+            return True
+
+        parent_map = {c:p for p in tree.iter() for c in p}
+
+        elements_to_remove = list()
+        for element in tree.iterfind('.//w:nsid', namespace):
+            elements_to_remove.append(element)
+        for element in elements_to_remove:
+            parent_map[element].remove(element)
+
+        tree.write(full_path, xml_declaration=True)
+        return True
+
+
+    @staticmethod
+    def __remove_revisions(full_path: str) -> bool:
         try:
             tree, namespace = _parse_xml(full_path)
         except ET.ParseError as e:
@@ -208,7 +243,8 @@ class MSOfficeParser(ZipParser):
         """
         try:
             tree, namespace = _parse_xml(full_path)
-        except ET.ParseError:  # pragma: no cover
+        except ET.ParseError as e:  # pragma: no cover
+            logging.error("Unable to parse %s: %s", full_path, e)
             return False
 
         if len(namespace.items()) != 1:
@@ -269,6 +305,9 @@ class MSOfficeParser(ZipParser):
         if self.__remove_rsid(full_path) is False:
             return False
 
+        if self.__remove_nsid(full_path) is False:
+            return False  # pragma: no cover
+
         try:
             _sort_xml_attributes(full_path)
         except ET.ParseError as e:  # pragma: no cover
@@ -337,6 +376,7 @@ class LibreOfficeParser(ZipParser):
         }))
         self.files_to_omit = set(map(re.compile, {  # type: ignore
             r'^meta\.xml$',
+            r'^layout-cache$',
             r'^Configurations2/',
             r'^Thumbnails/',
         }))
