@@ -33,10 +33,10 @@ class TorrentParser(abstract.AbstractParser):
         return True
 
 
-class _BencodeHandler():
+class _BencodeHandler:
     """
     Since bencode isn't that hard to parse,
-    MAT2 comes with its own parser, based on the spec
+    mat2 comes with its own parser, based on the spec
     https://wiki.theory.org/index.php/BitTorrentSpecification#Bencoding
     """
     def __init__(self):
