@@ -1,10 +1,12 @@
+import subprocess
+import functools
 import os
 import logging
 
 from typing import Dict, Union
 
 from . import exiftool
-from . import subprocess
+from . import bubblewrap
 
 
 class AbstractFFmpegParser(exiftool.ExiftoolParser):
@@ -32,9 +34,12 @@ class AbstractFFmpegParser(exiftool.ExiftoolParser):
                '-flags:a', '+bitexact',  # don't add any metadata
                self.output_filename]
         try:
-            subprocess.run(cmd, check=True,
-                           input_filename=self.filename,
-                           output_filename=self.output_filename)
+            if self.sandbox:
+                bubblewrap.run(cmd, check=True,
+                               input_filename=self.filename,
+                               output_filename=self.output_filename)
+            else:
+                subprocess.run(cmd, check=True)
         except subprocess.CalledProcessError as e:
             logging.error("Something went wrong during the processing of %s: %s", self.filename, e)
             return False
@@ -130,6 +135,7 @@ class MP4Parser(AbstractFFmpegParser):
     }
 
 
+@functools.lru_cache()
 def _get_ffmpeg_path() -> str:  # pragma: no cover
     ffmpeg_path = '/usr/bin/ffmpeg'
     if os.path.isfile(ffmpeg_path):
