@@ -127,6 +127,11 @@ class TestGetMeta(unittest.TestCase):
         self.assertEqual(meta['Model'], 'C7070WZ')
         self.assertEqual(meta['ModifyDate'], '2005:12:26 17:09:35')
 
+    def test_wav(self):
+        p = audio.WAVParser('./tests/data/dirty.wav')
+        meta = p.get_meta()
+        self.assertEqual(meta['Artist'], 'jvoisin')
+
     def test_mp3(self):
         p = audio.MP3Parser('./tests/data/dirty.mp3')
         meta = p.get_meta()
@@ -301,6 +306,11 @@ class TestCleaning(unittest.TestCase):
             'parser': images.JPGParser,
             'meta': {'Comment': 'Created with GIMP'},
             'expected_meta': {},
+        }, {
+            'name': 'wav',
+            'parser': audio.WAVParser,
+            'meta': {'Comment': 'Zomg, a comment!'},
+            'expected_meta': {},
         }, {
             'name': 'mp3',
             'parser': audio.MP3Parser,
@@ -431,14 +441,16 @@ class TestCleaning(unittest.TestCase):
             'meta': {
                 'Encoder':  'HandBrake 0.9.4 2009112300',
             },
-            'expected_meta':
-            {'CompatibleBrands': ['isom', 'iso2', 'avc1', 'mp41'],
+            'expected_meta': {
+                'CompatibleBrands': ['isom', 'iso2', 'avc1', 'mp41'],
                 'CompressorID': 'avc1',
                 'GraphicsMode': 'srcCopy',
                 'HandlerDescription': 'SoundHandler',
                 'HandlerType': 'Metadata',
                 'HandlerVendorID': 'Apple',
                 'MajorBrand': 'MP4  Base Media v1 [IS0 14496-12:2003]',
+                'MediaDataOffset': 48,
+                'MediaDataSize': 379872,
                 'MediaHeaderVersion': 0,
                 'MinorVersion': '0.2.0',
                 'MovieDataOffset': 48,
@@ -474,19 +486,23 @@ class TestCleaning(unittest.TestCase):
             shutil.copy('./tests/data/dirty.' + case['name'], target)
             p1 = case['parser'](target)
 
-            meta = p1.get_meta()
-            for k, v in case['meta'].items():
+            for k, v in p1.get_meta().items():
+                if k not in case['meta']:
+                    continue
                 if isinstance(v, dict):
                     for _k, _v in v.items():
-                        self.assertEqual(meta[k][_k], _v)
+                        if _k in case['meta'][k]:
+                            self.assertEqual(_v, case['meta'][k][_k])
                 else:
-                    self.assertEqual(meta[k], v)
+                    self.assertEqual(v, case['meta'][k])
 
             p1.lightweight_cleaning = True
             self.assertTrue(p1.remove_all())
 
             p2 = case['parser'](p1.output_filename)
-            self.assertEqual(p2.get_meta(), case['expected_meta'])
+            for k, v in p2.get_meta().items():
+                self.assertIn(k, case['expected_meta'])
+                self.assertEqual(v, case['expected_meta'][k])
             self.assertTrue(p2.remove_all())
 
             os.remove(target)
